function cdata = ldIcon(filename, d)
%--------------------------------------------------------------------------
% localloadiconcdata: Loads CData from the icon files (PNG, GIF or MAT) in
% toolbox/matlab/icons or ./img/, depending on variable d.
%
%   Usage: cdata = localloadiconcdata(filename, d)
%
% Defined variables:
%   filename:   the icon image name
%   d:          a path showing where the icon (defined by filename) is; if
%               it'sempty, to load from toolbox/matlab/icons.
%
% REFERENCE:
%   MATLAB uitoolfactory.m, to load the icons for the toolbar
%--------------------------------------------------------------------------

% Load cdata from *.gif file
persistent ICONROOT
if(isempty(d))
    if isempty(ICONROOT)
        ICONROOT = fullfile(matlabroot,'toolbox','matlab','icons',filesep);
    end
    d1 = ICONROOT;
else
    d1 = d;
end

if length(filename)>3 && strncmp(filename(end-3:end),'.gif',4)
    [cdata,map] = imread([d1,filename]);
    % Set all white (1,1,1) colors to be transparent (nan)
    ind = map(:,1)+map(:,2)+map(:,3)==3;
    map(ind) = NaN;
    cdata = ind2rgb(cdata,map);
    
    % Load cdata from *.png file
elseif length(filename)>3 && strncmp(filename(end-3:end),'.png',4)
    [cdata map alpha] = imread([d1,filename],'Background','none');
    if(isempty(d))
        % Converting 16-bit integer colors to MATLAB colorspec
        cdata = double(cdata) / 65535.0;
    else
        % Converting 8-bit integer colors to MATLAB colorspec
        cdata = double(cdata) / 255.0;
    end
    % Set all transparent pixels to be transparent (nan)
    cdata(alpha==0) = NaN;
    
    % Load cdata from *.mat file
else
    temp = load([d1,filename],'cdata');
    cdata = temp.cdata;
end

end
