function handles=makePanel(mywindow)
%makePanel Makes the 3800 user interface
%   The controls for each of the 8 channels are:
%'Status'          'Waveform'    'TriggerSource'         'SyncOutputSource' 
%'GateConnection'  'PulseDelay'  'PulseWidth'            'PulseInterphase' 
%'PulsePeriod'     'TrainDelay'  'TrainWidth'            'TrainNum'
%'TrainPeriod'     'PairedStart' 'PairedPulseDirection'  'PairedChange'
%'StepStart'       'StepChange'  'Offset'                'Pulse1' 
%'Pulse2'          'Combo' 
%
%  The controls for the toolbar are:
%'Open file'   'Save file'    'Connect'     'Upload'    'Download'
%
%%  Get the names within controls from the dll.
% load('3800names');
% add path to icons addpath('c:/matlab/icons')
 AM = NET.addAssembly([pwd '\libraries\AMS3800Interface_NET.dll']);
ControlNames=fieldnames(AMS3800Interface_NET.Ams3800Channel);
StatusNames = cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.Status)));
TriggerSourceNames = cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.TriggerSource)));
WaveformNames=cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.Waveform)));
GateConnectionNames=cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.GateConnection)));
TimeResolutionNames = cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.TimeResolution)));
PairedPulseDirectionNames= cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.PairedPulseDirection)));
SyncOutputSourceNames = cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.SyncOutputSource)));
ControlModeNames = cell(System.Enum.GetNames(GetType(AMS3800Interface_NET.ControlMode)));
% Type 1 = pushbutton  Type 2 = popupmenu  Type 3= time edit box
% Type 4 = unsigned integer edit box   Type 5 = voltage edit box
% Type 6 = 8 checkboxes  
% Type 7 = toolstrip
% Control Names were taken from ControlNames cell
%%  
%% Set up an array of how I want to order the controls
global cntrlOrderType;
cntrlOrderType={'Status' 1; 'Waveform' 2; 'TriggerSource' 2; ...
    'SyncOutputSource' 2; 'GateConnection' 2; ...
    'PulseDelay' 3; 'PulseWidth' 3; 'PulseInterphase' 3; 'PulsePeriod' 3; ...
    'TrainDelay' 3; 'TrainWidth' 3; 'TrainNum' 4; 'TrainPeriod' 3; ...
    'PairedStart' 3; 'PairedPulseDirection' 2; 'PairedChange' 3; ...
    'StepStart' 5; 'StepChange' 5; 'Offset' 5; 'Pulse1' 5; 'Pulse2' 5;  ...
    'Combo' 6;};
%find(not(cellfun('isempty',strfind(ControlNames, cell2mat(cntrlOrder(2))))))
%%  Build Toolbar  UserData = channel,name,type,value  for toolbar chan=0
    h=guihandles(mywindow);
    h.toolbar=uitoolbar(mywindow);
    h.tbr_open=uipushtool(h.toolbar, ...
            'CData', ldIcon('file_open.png',''),...
            'TooltipString','Open file',...
            'UserData', {0 'Open file' 7 0}, ...
            'ClickedCallback', {@processUserInput});

   h.tbr_save=uipushtool(h.toolbar, ...
        'CData', ldIcon('file_save.png',''),...
        'TooltipString','Save file',...
        'UserData', {0 'Save file' 7 0}, ...
        'ClickedCallback', {@processUserInput});
    h.tbr_blank=uipushtool(h.toolbar);
    h.tbr_enable=uipushtool(h.toolbar, ...
        'CData', ldIcon('\images\power off_20.png',pwd),...
        'TooltipString','Enable/Disable',...
        'UserData', {0 'Enable' 7 0}, ...
        'ClickedCallback', {@processUserInput});
    h.tbr_blank=uipushtool(h.toolbar);
       
    for i=1:33
           h.tbr_blank=uipushtool(h.toolbar);
    end

%     h.tbr_control=uipushtool(h.toolbar, ...
%             'CData', ldIcon('tool_legend.png',''),...
%             'TooltipString','Control',...
%             'UserData', {0 'Control' 7 1}, ...
%             'ClickedCallback', {@processUserInput});    
        
        h.tbr_blank=uipushtool(h.toolbar);
        h.tbr_blank=uipushtool(h.toolbar);
       
    h.tbr_connect=uipushtool(h.toolbar, ...
        'CData', ldIcon('\images\disconnect-icon.png',pwd),...
        'TooltipString','Connect/Disconnect',...
        'UserData', {0 'Connect' 7 0}, ...
        'Separator', 'on', ...
        'ClickedCallback', {@processUserInput}); 
 

     h.tbr_upload=uipushtool(h.toolbar, ...
        'CData', ldIcon('\images\upload.png',pwd),...
        'TooltipString','Upload',...
        'UserData', {0 'Upload' 7 0}, ...
        'Separator', 'on', ...
        'Enable', 'off', ...
        'ClickedCallback', {@processUserInput}); 
%      h.tbr_download=uipushtool(h.toolbar, ...
%         'CData', ldIcon('\images\download.png',pwd),...
%         'TooltipString','Download',...
%         'UserData', {0 'Download' 7 0}, ...
%         'ClickedCallback', {@processUserInput}); 
 %% 
 %% Channel controls
   sizeCntrl=size(cntrlOrderType,1);
   Ptop=625;
   Top=595;
   hgt=18;
   vshft=22;
   Shift=0;
   
   % Put Control labels for each row
   for lbl=1:sizeCntrl
       [Shift, vshft]=vertAdj( Shift,vshft, lbl);
       vt=Top-lbl*vshft-Shift+5;
       h.label(lbl)=uicontrol('Style','text',...
        'Position',[0 vt 95 hgt-2],...
        'String',cntrlOrderType(lbl,1));
   end
   
   % Put Channel controls in a panel
    for chan=1:8
        Shift=0;
        s_ch=num2str(chan);
        h.Channel(chan)=uipanel(...
            'Title',['Channel ' s_ch], ...
            'Tag', ['Channel_' s_ch], ...
            'Units','pixels', ...
            'Position',[95+(chan-1)*120,5,120,Ptop], ...
            'BackgroundColor',[.6,0.6,0.6]);
        % put each control in the panel
        for cntrl=1:sizeCntrl %22
            %  UserData = channel,name,type,extravalue
           [Shift, vshft]=vertAdj( Shift,vshft, cntrl);
           vt=Top-cntrl*vshft-Shift;
            nstr=cell2mat(cntrlOrderType(cntrl,1));
            cntlType=cell2mat(cntrlOrderType(cntrl,2));
            switch cntlType
                case 1
                    h.(genvarname(nstr))(chan) = uicontrol('Parent',h.Channel(chan), ...
                        'Tag', [nstr s_ch], ...
                        'UserData', {chan nstr cntlType 0}, ...
                        'style', 'pushbutton' ,...
                        'position',[4 vt-10 40 40] ,...
                        'string', 'OFF', ...
                        'callback', {@processUserInput});
                case 2
                   h.(genvarname(nstr))(chan)=uicontrol('Parent',h.Channel(chan), ...
                        'Tag', [nstr s_ch], ...
                        'UserData', {chan nstr cntlType 0}, ...
                        'style', 'popupmenu'   ,...
                        'FontSize', 8 , ...
                        'position',[4 vt 100 hgt] ,...
                        'string', eval(genvarname([nstr 'Names'])), ...
                        'callback', {@processUserInput});
                case 3
                    h.(genvarname(nstr))(chan)=uicontrol('Parent',h.Channel(chan), ...
                        'Tag', [nstr s_ch], ...
                        'UserData', {chan nstr cntlType 0}, ...
                        'style', 'edit' ,...
                        'position',[4 vt 100 hgt] ,...
                        'BackgroundColor','white', ...
                        'HorizontalAlignment', 'right', ...
                        'callback', {@processUserInput});
                case 4
                    h.(genvarname(nstr))(chan)=uicontrol('Parent',h.Channel(chan), ...
                        'Tag', [nstr s_ch], ...
                        'UserData', {chan nstr cntlType 0}, ...
                        'style', 'edit' ,...
                        'position',[4 vt 60 hgt] ,...
                        'BackgroundColor','white', ...
                        'HorizontalAlignment', 'right', ...
                        'callback', {@processUserInput});         
                case 5
                    h.(genvarname(nstr))(chan)=uicontrol('Parent',h.Channel(chan), ...
                        'Tag', [nstr s_ch], ...
                        'UserData', {chan nstr cntlType 0}, ...
                        'style', 'edit' ,...
                        'position',[4 vt 100 hgt] ,...
                        'BackgroundColor','white', ...
                        'HorizontalAlignment', 'right', ...
                        'callback', {@processUserInput});     
                case 6
                    inc=-1;
                    nlbl=0;
                    for chk=8:-1:1
                        inc=inc+1;
                        nlbl=nlbl+1;
                        slbl=num2str(nlbl);
                        if chk==4 
                            Shift=Shift+20;
                            vt=Top-cntrl*vshft-Shift;
                            inc=0;
                        end
                         h.(genvarname(nstr))(chan).c(chk)=uicontrol('Parent',h.Channel(chan), ...
                            'Tag', [nstr s_ch ], ...
                            'string', slbl, ...
                            'UserData', {chan nstr cntlType,nlbl}, ...
                            'style', 'checkbox' ,...
                            'position',[4+25*inc vt 25 hgt] ,...
                            'callback', {@processUserInput});
                    end
            end
        end
    end
    handles=h;
    
end       

function [v1, v2]=vertAdj( v1p,v2p, pos)
    v1=v1p;
    v2=v2p;
    switch pos
        case 2 
            v1 = 15;
            v2 = 23;
        case 6
            v1 = v1p+25;
            v2 = 21;
        case 10
            v1 = v1p+10;
        case 14
            v1 = v1p+10;
        case 16
            v1 = v1p+4;
       case 17
            v1 = v1p+10;
        case 19
            v1 = v1p+10;
       case 22
            v1 = v1p+10;
    end
end


