function UserOutput=processUserInput(hObject, eventdata)
global my3800
global Channels
import AMS3800Interface_NET.*
%processUserInput Handles all of the user input
%   The user input is sent by these controls for each of the 8 channels:
%'Status'          'Waveform'    'TriggerSource'         'SyncOutputSource' 
%'GateConnection'  'PulseDelay'  'PulseWidth'            'PulseInterphase' 
%'PulsePeriod'     'TrainDelay'  'TrainWidth'            'TrainNum'
%'TrainPeriod'     'PairedStart' 'PairedPulseDirection'  'PairedChange'
%'StepStart'       'StepChange'  'Offset'                'Pulse1' 
%'Pulse2'          'Combo' 
%
%  The controls for the toolbar are:
%'Open file' 'Save file' 'Enable' 'Control' 'Connect' 'Upload' 'Download'
%
%
h=guidata(hObject); %get graphic data
% Identify the control
[channel,control,cntlType,value] = getUserData(hObject);
% tmpdsp=sprintf('ch=%d    btn=%s    type=%d    val=%s ',channel,control,cntlType,value);
% disp(tmpdsp);
%
connectData=get(h.tbr_connect, 'UserData');
commsOK=cell2mat(connectData(4));
UserOutput=1;
% Do something with the user input
if commsOK  % do stuff with a good instrument connection
    switch control
        case 'Connect'
            connected=my3800.isConnected();
            if connected 
                my3800.closeInterface();
                set(hObject,'CData', ldIcon('\images\disconnect-icon.png',pwd), ...
                'UserData', {0 'Connect' 7 0});
                set(h.tbr_upload,'Enable','off');
            end
         case 'Enable'
            if str2double(value)==0 %Enable
                my3800.SetListValue(0,IndexListControls.IdxGlobalEnable, 1)
                set(hObject,'CData', ldIcon('\images\power on_20.png',pwd), ...
                    'UserData', {0 'Enable' 7 1});
            else  %Disable
                 my3800.SetListValue(0,IndexListControls.IdxGlobalEnable, 0)
                 set(hObject,'CData', ldIcon('\images\power off_20.png',pwd), ...
                     'UserData', {0 'Enable' 7 0});
            end
        case 'Status'
            if strcmp(get(hObject,'string'),'OFF') %off
            my3800.SetListValue(channel-1, ...
                AMS3800Interface_NET.IndexListControls.IdxStatus, ...
                1);
             set(hObject,'string', 'ON','BackgroundColor','green');
             
            else
            my3800.SetListValue(channel-1, ...
                AMS3800Interface_NET.IndexListControls.IdxStatus, ...
                0);
             set(hObject,'string', 'OFF','BackgroundColor',[240/255 240/255 240/255]);
            end  
        case {'Waveform','TriggerSource','SyncOutputSource','GateConnection','PairedPulseDirection'}
             my3800.SetListValue(channel-1, getListCommand(control), ...
                str2double(value)-1);
        case {'PulseDelay','PulseWidth','PulseInterphase','PulsePeriod', ...
              'TrainDelay','TrainWidth','TrainPeriod','PairedStart','PairedChange'}
             my3800.SetTimeValue(channel-1, getTimeCommand(control), ...
                 str2double(value));
        case {'StepStart','StepChange','Offset','Pulse1','Pulse2'}
            my3800.SetAmpValue(channel-1,getAmpCommand(control),...
                str2double(value)*1000);
        case {'Combo', 'TrainNum'}
             my3800.SetListValue(channel-1, getListCommand(control), ...
                str2double(value));            
        case 'Upload'
            set(findall(h.toolbar,'-property','Enable'),'Enable','off');
            set(findall(h.Channel,'-property','Enable'),'Enable','off');
            drawnow;
             Channels=my3800.GetAllChanVals;
            LoadPanel(hObject,false);
            set(findall(h.toolbar,'-property','Enable'),'Enable','on')
            set(findall(h.Channel,'-property','Enable'),'Enable','on')            

%         case 'Control'
%              set(h.tbr_connect,'CData', ldIcon('\images\disconnect-icon.png',pwd), ...
%                 'UserData', {0 'Connect' 7 0});
%             my3800.SetListValue(0, ...
%                  AMS3800Interface_NET.IndexListControls.IdxGlobalControlMode,...
%                  0);
%              my3800.closeInterface();        
        case 'Open file'
           ReadAMSFile(hObject);
        case 'Save file'
           WriteAMSFile();
        otherwise
             UserOutput=0;
    end
    
else  % only do certain things when no instrument connection
    reply= AMS3800Interface_NET.AmsErrors.IO_Error;
    switch control
        case 'Connect'
            connected=my3800.isConnected();
            if ~connected 
                reply=my3800.getInterface(); 
            else
                my3800.closeInterface();
                reply=my3800.getInterface(); 
            end
            connected=my3800.isConnected();
            if ~connected 
                errordlg('No connection. Try pluging in the USB')
            else
                if reply ~=AMS3800Interface_NET.AmsErrors.IO_OK
                    my3800.closeInterface();
                    errordlg('No connection. Try selecting computer on the front panel')
                else
                    commsOK=connected && reply==AMS3800Interface_NET.AmsErrors.IO_OK 
                    if commsOK
                        set(hObject,'CData', ldIcon('\images\connect-icon.png',pwd), ...
                        'UserData', {0 'Connect' 7 commsOK} );
                        set(h.tbr_upload,'Enable','on');
                    end
                end
            end            
         case 'Open file'
           ReadAMSFile(hObject);
         case 'Save file'
           WriteAMSFile();              
            
        otherwise
             UserOutput=0;
    end
end

% 
guidata(hObject,h) ;%save graphic data

end


%
function [chan,btnType,cntlType,val] = getUserData(hObject)
h=guidata(hObject); %get graphic data
bntData=get(hObject,'UserData');
chan=cell2mat(bntData(1));
btnType=cell2mat(bntData(2));
cntlType=cell2mat(bntData(3));
myValue=cell2mat(bntData(4));
if cntlType < 7 
    value=get(hObject,'Value');
end


% hmm=get(hObject,'string');
% Type 1 = pushbutton  Type 2 = popupmenu  Type 3= time edit box
% Type 4 = unsigned integer edit box   Type 5 = voltage edit box
% Type 6 = 8 checkboxes   Type7 = toolbar buttons
% vals=fieldnames(h.Combo(1))
% vals=get(h.Combo(1).c(1))
switch cntlType
    case 1
        val=num2str(myValue);
    case 2
      val= num2str(value);
    case 3
       val = timeNum(hObject);
    case 4
       val = num2str(trainNum(hObject));
    case 5
       val = voltNum(hObject);
    case 6
        vals=get(h.Combo(chan).c, 'Value');
        vals=cell2mat(vals);
        vals=mat2str(vals');
        vals=vals(2:size(vals,2)-1);
        val= num2str(bin2dec(vals));
    case 7 
        val=num2str(myValue);
end

end

